### Installation
The module, topis requires pandas, math and sys modules to function
This module is used to print the score and rank after using TOPSIS (Technique for Order Preference based on Similarity to Ideal Solution)

Usages: python topsis.py <InputDataFile> <Weights> <Impacts>
	
```sh
$ pip install python-topcmd
$ python topsis.py myData.csv “1,2,1,1” “+,+,-+”
```
### License
MIT
### Author
Sahil Ahuja
